<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans https://git.spip.net/spip/filtres_images.git

return [

	// I
	'images_description' => 'Filtres de transformation d’images et de couleurs',
	'images_slogan' => 'Filtres de transformation d’images et de couleurs',
];
